@@ -1,9 +1,11 @@
 import numpy as np
 import xarray
 import matplotlib.pyplot as plt
-class obj():
+class earthobj:
     def __init__(self,DataArray):
         self.DataArray = DataArray
+    def testprint(self):
+        print('Done')
     def plotshow(self,lst=True):
         self.lst=lst
         if type(self.DataArray) == xarray.core.dataarray.DataArray:
